@@ -27,8 +27,6 @@
 #include "string.h"
 #include "glibintl.h"
 
-#include <gioalias.h>
-
 /**
  * SECTION:gbufferedoutputstream
  * @short_description: Buffered Output Stream
@@ -763,6 +761,3 @@ g_buffered_output_stream_close_finish (GOutputStream        *stream,
 
   return TRUE;
 }
-
-#define __G_BUFFERED_OUTPUT_STREAM_C__
-#include "gioaliasdef.c"
