@@ -43,7 +43,6 @@
 #include "gdbusprivate.h"
 
 #include "glibintl.h"
-#include "gioalias.h"
 
 struct _GDBusAuthMechanismSha1Private
 {
@@ -360,8 +359,8 @@ keyring_lookup_entry (const gchar  *cookie_context,
   guint n;
   gchar **lines;
 
-  g_return_val_if_fail (cookie_context != NULL, FALSE);
-  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+  g_return_val_if_fail (cookie_context != NULL, NULL);
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
   ret = NULL;
   path = NULL;
@@ -525,7 +524,7 @@ keyring_acquire_lock (const gchar  *path,
       num_tries++;
       if (num_tries == 50)
         {
-          /* ok, we slept 50*10ms = 0.5 seconds.. Conclude that the lock-file must be
+          /* ok, we slept 50*10ms = 0.5 seconds. Conclude that the lock file must be
            * stale (nuke the it from orbit)
            */
           if (g_unlink (lock) != 0)
@@ -533,12 +532,12 @@ keyring_acquire_lock (const gchar  *path,
               g_set_error (error,
                            G_IO_ERROR,
                            g_io_error_from_errno (errno),
-                           _("Error deleting stale lock-file `%s': %s"),
+                           _("Error deleting stale lock file `%s': %s"),
                            lock,
                            strerror (errno));
               goto out;
             }
-          _log ("Deleted stale lock-file `%s'", lock);
+          _log ("Deleted stale lock file `%s'", lock);
           break;
         }
     }
@@ -564,7 +563,7 @@ keyring_acquire_lock (const gchar  *path,
       g_set_error (error,
                    G_IO_ERROR,
                    g_io_error_from_errno (errno),
-                   _("Error creating lock-file `%s': %s"),
+                   _("Error creating lock file `%s': %s"),
                    lock,
                    strerror (errno));
       goto out;
@@ -594,7 +593,7 @@ keyring_release_lock (const gchar  *path,
       g_set_error (error,
                    G_IO_ERROR,
                    g_io_error_from_errno (errno),
-                   _("Error closing (unlinked) lock-file `%s': %s"),
+                   _("Error closing (unlinked) lock file `%s': %s"),
                    lock,
                    strerror (errno));
       goto out;
@@ -604,7 +603,7 @@ keyring_release_lock (const gchar  *path,
       g_set_error (error,
                    G_IO_ERROR,
                    g_io_error_from_errno (errno),
-                   _("Error unlinking lock-file `%s': %s"),
+                   _("Error unlinking lock file `%s': %s"),
                    lock,
                    strerror (errno));
       goto out;
@@ -1217,6 +1216,3 @@ mechanism_client_shutdown (GDBusAuthMechanism   *mechanism)
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
-
-#define __G_DBUS_AUTH_MECHANISM_SHA1_C__
-#include "gioaliasdef.c"
