@@ -709,7 +709,7 @@ g_dbus_message_get_unix_fd_list (GDBusMessage  *message)
 /**
  * g_dbus_message_set_unix_fd_list:
  * @message: A #GDBusMessage.
- * @fd_list: A #GUnixFDList or %NULL.
+ * @fd_list: (allow-none): A #GUnixFDList or %NULL.
  *
  * Sets the UNIX file descriptors associated with @message. As a
  * side-effect the %G_DBUS_MESSAGE_HEADER_FIELD_NUM_UNIX_FDS header
@@ -899,7 +899,7 @@ read_string (GMemoryInputStream    *mis,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
                        _("Wanted to read %lu bytes but got EOF"),
-                       to_read);
+                       (gulong)to_read);
           goto fail;
         }
 
@@ -924,7 +924,7 @@ read_string (GMemoryInputStream    *mis,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
                    _("Expected valid UTF-8 string but found invalid bytes at byte offset %d (length of string is %d). "
-                     "The valid UTF-8 string up until that that point was `%s'"),
+                     "The valid UTF-8 string up until that point was `%s'"),
                    offset,
                    (gint) s->len,
                    valid_str);
@@ -1403,7 +1403,7 @@ parse_value_from_blob (GMemoryInputStream    *mis,
       g_set_error (&local_error,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Error deserializing GVariant with type-string `%s' from the D-Bus wire format"),
+                   _("Error deserializing GVariant with type string `%s' from the D-Bus wire format"),
                    s);
       g_free (s);
       goto fail;
@@ -2035,7 +2035,7 @@ append_value_to_blob (GVariant             *value,
       g_set_error (error,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Error serializing GVariant with type-string `%s' to the D-Bus wire format"),
+                   _("Error serializing GVariant with type string `%s' to the D-Bus wire format"),
                    g_variant_get_type_string (value));
       goto fail;
     }
@@ -2268,8 +2268,11 @@ g_dbus_message_to_blob (GDBusMessage          *message,
 
   g_data_output_stream_put_uint32 (dos, body_size, NULL, NULL);
 
+  if (!g_output_stream_close (G_OUTPUT_STREAM (dos), NULL, error))
+    goto out;
+
   *out_size = size;
-  ret = g_memdup (g_memory_output_stream_get_data (mos), size);
+  ret = g_memory_output_stream_steal_data (mos);
 
  out:
   g_object_unref (dos);
