@@ -34,7 +34,6 @@
 #include <glib.h>
 #include <glibintl.h>
 
-#include "gioalias.h"
 
 G_DEFINE_ABSTRACT_TYPE (GSettingsBackend, g_settings_backend, G_TYPE_OBJECT)
 
@@ -828,12 +827,12 @@ g_settings_backend_write (GSettingsBackend *backend,
  * old values.
  */
 gboolean
-g_settings_backend_write_keys (GSettingsBackend *backend,
+g_settings_backend_write_tree (GSettingsBackend *backend,
                                GTree            *tree,
                                gpointer          origin_tag)
 {
   return G_SETTINGS_BACKEND_GET_CLASS (backend)
-    ->write_keys (backend, tree, origin_tag);
+    ->write_tree (backend, tree, origin_tag);
 }
 
 /*< private >
@@ -855,24 +854,6 @@ g_settings_backend_reset (GSettingsBackend *backend,
     ->reset (backend, key, origin_tag);
 }
 
-/*< private >
- * g_settings_backend_reset_path:
- * @backend: a #GSettingsBackend implementation
- * @name: the name of a key or path
- * @origin_tag: the origin tag
- *
- * "Resets" the named path.  This means that every key under the path is
- * reset.
- */
-void
-g_settings_backend_reset_path (GSettingsBackend *backend,
-                               const gchar      *path,
-                               gpointer          origin_tag)
-{
-  G_SETTINGS_BACKEND_GET_CLASS (backend)
-    ->reset_path (backend, path, origin_tag);
-}
-
 /*< private >
  * g_settings_backend_get_writable:
  * @backend: a #GSettingsBackend implementation
@@ -1025,6 +1006,10 @@ g_settings_backend_get_default (void)
             g_error ("No GSettingsBackend implementations exist.");
 
           extension = extensions->data;
+
+          if (strcmp (g_io_extension_get_name (extension), "memory") == 0)
+            g_message ("Using the 'memory' GSettings backend.  Your settings "
+                       "will not be saved or shared with other applications.");
         }
 
       extension_type = g_io_extension_get_type (extension);
@@ -1040,7 +1025,7 @@ g_settings_backend_get_default (void)
  * g_settings_backend_get_permission:
  * @backend: a #GSettingsBackend
  * @path: a path
- * @returns: a non-%NULL #GPermission
+ * @returns: a non-%NULL #GPermission. Free with g_object_unref()
  *
  * Gets the permission object associated with writing to keys below
  * @path on @backend.
@@ -1077,6 +1062,3 @@ g_settings_backend_sync_default (void)
   if (class->sync)
     class->sync (backend);
 }
-
-#define __G_SETTINGS_BACKEND_C__
-#include "gioaliasdef.c"
