@@ -38,7 +38,6 @@
 #include "gasynchelper.h"
 #include "glibintl.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gunixinputstream
@@ -50,8 +49,8 @@
  * UNIX file descriptor, including asynchronous operations. The file
  * descriptor must be selectable, so it doesn't work with opened files.
  *
- * Note that <filename>&lt;gio/gunixinputstream.h&gt;</filename> belongs 
- * to the UNIX-specific GIO interfaces, thus you have to use the 
+ * Note that <filename>&lt;gio/gunixinputstream.h&gt;</filename> belongs
+ * to the UNIX-specific GIO interfaces, thus you have to use the
  * <filename>gio-unix-2.0.pc</filename> pkg-config file when using it.
  */
 
@@ -116,10 +115,6 @@ static gboolean g_unix_input_stream_close_finish (GInputStream         *stream,
 static void
 g_unix_input_stream_finalize (GObject *object)
 {
-  GUnixInputStream *stream;
-  
-  stream = G_UNIX_INPUT_STREAM (object);
-
   G_OBJECT_CLASS (g_unix_input_stream_parent_class)->finalize (object);
 }
 
@@ -505,6 +500,7 @@ g_unix_input_stream_read_async (GInputStream        *stream,
   source = _g_fd_source_new (unix_stream->priv->fd,
 			     G_IO_IN,
 			     cancellable);
+  g_source_set_name (source, "GUnixInputStream");
   
   g_source_set_callback (source, (GSourceFunc)read_async_cb, data, g_free);
   g_source_attach (source, g_main_context_get_thread_default ());
@@ -647,6 +643,3 @@ g_unix_input_stream_close_finish (GInputStream  *stream,
   /* Failures handled in generic close_finish code */
   return TRUE;
 }
-
-#define __G_UNIX_INPUT_STREAM_C__
-#include "gioaliasdef.c"
