@@ -301,6 +301,7 @@ test_expander (void)
   GInputStream *mem, *cstream;
   GOutputStream *mem_out, *cstream_out;
   GConverter *expander;
+  GConverter *converter;
   GError *error;
   int i;
 
@@ -326,6 +327,9 @@ test_expander (void)
 					     NULL);
   cstream = g_converter_input_stream_new (mem, expander);
   g_assert (g_converter_input_stream_get_converter (G_CONVERTER_INPUT_STREAM (cstream)) == expander);
+  g_object_get (cstream, "converter", &converter, NULL);
+  g_assert (converter == expander);
+  g_object_unref (converter);
   g_object_unref (mem);
 
   total_read = 0;
@@ -350,6 +354,10 @@ test_expander (void)
 
   mem_out = g_memory_output_stream_new (NULL, 0, g_realloc, g_free);
   cstream_out = g_converter_output_stream_new (mem_out, expander);
+  g_assert (g_converter_output_stream_get_converter (G_CONVERTER_OUTPUT_STREAM (cstream_out)) == expander);
+  g_object_get (cstream_out, "converter", &converter, NULL);
+  g_assert (converter == expander);
+  g_object_unref (converter);
   g_object_unref (mem_out);
 
   for (i = 0; i < sizeof(unexpanded_data); i++)
@@ -571,6 +579,8 @@ test_corruption (GZlibCompressorFormat format, gint level)
   GInputStream *istream0, *istream1, *cistream1;
   GOutputStream *ostream1, *ostream2, *costream1;
   GConverter *compressor, *decompressor;
+  GZlibCompressorFormat fmt;
+  gint lvl;
 
   data0 = g_malloc (DATA_LENGTH * sizeof (guint32));
   for (i = 0; i < DATA_LENGTH; i++)
@@ -588,6 +598,11 @@ test_corruption (GZlibCompressorFormat format, gint level)
   g_assert_no_error (error);
 
   g_object_unref (costream1);
+
+  g_converter_reset (compressor);
+  g_object_get (compressor, "format", &fmt, "level", &lvl, NULL);
+  g_assert_cmpint (fmt, ==, format);
+  g_assert_cmpint (lvl, ==, level);
   g_object_unref (compressor);
   data1 = g_memory_output_stream_get_data (G_MEMORY_OUTPUT_STREAM (ostream1));
   data1_size = g_memory_output_stream_get_data_size (
@@ -608,6 +623,13 @@ test_corruption (GZlibCompressorFormat format, gint level)
     g_memory_output_stream_get_data_size (G_MEMORY_OUTPUT_STREAM (ostream2)));
   g_assert (memcmp (data0, g_memory_output_stream_get_data (
     G_MEMORY_OUTPUT_STREAM (ostream2)), DATA_LENGTH * sizeof (guint32)) == 0);
+  g_object_unref (istream1);
+  g_converter_reset (decompressor);
+  g_object_get (decompressor, "format", &fmt, NULL);
+  g_assert_cmpint (fmt, ==, format);
+  g_object_unref (decompressor);
+  g_object_unref (cistream1);
+  g_object_unref (ostream2);
 }
 
 typedef struct {
@@ -621,6 +643,8 @@ test_roundtrip (gconstpointer data)
 {
   const CompressorTest *test = data;
 
+  g_test_bug ("162549");
+
   test_corruption (test->format, test->level);
 }
 
@@ -720,6 +744,8 @@ main (int   argc,
   g_type_init ();
   g_test_init (&argc, &argv, NULL);
 
+  g_test_bug_base ("http://bugzilla.gnome.org/");
+
   g_test_add_func ("/converter-input-stream/expander", test_expander);
   g_test_add_func ("/converter-input-stream/compressor", test_compressor);
 
