@@ -77,7 +77,6 @@
 #  endif
 #endif
 
-#include "galias.h"
 
 #ifndef G_OS_WIN32
 static void stack_trace (char **args);
@@ -303,6 +302,3 @@ stack_trace (char **args)
 }
 
 #endif /* !G_OS_WIN32 */
-
-#define __G_BACKTRACE_C__
-#include "galiasdef.c"
