@@ -45,12 +45,15 @@
 
 #include "gstdio.h"
 
-#include "galias.h"
 
 #if !defined (G_OS_UNIX) && !defined (G_OS_WIN32) && !defined (G_OS_BEOS)
 #error Please port this to your operating system
 #endif
 
+#if defined (_MSC_VER) && !defined(_WIN64)
+#undef _wstat
+#define _wstat _wstat32
+#endif
 
 /**
  * g_access:
@@ -422,6 +425,14 @@ g_chdir (const gchar *path)
 #endif
 }
 
+/**
+ * GStatBuf:
+ *
+ * A type corresponding to the appropriate struct type for the stat
+ * system call, depending on the platform and/or compiler being used.
+ *
+ * See g_stat() for more information.
+ **/
 /**
  * g_stat: 
  * @filename: a pathname in the GLib file name encoding (UTF-8 on Windows)
@@ -434,6 +445,20 @@ g_chdir (const gchar *path)
  * not look at the ACL at all. Thus on Windows the protection bits in
  * the st_mode field are a fabrication of little use.
  * 
+ * On Windows the Microsoft C libraries have several variants of the
+ * <structname>stat</structname> struct and stat() function with names
+ * like "_stat", "_stat32", "_stat32i64" and "_stat64i32". The one
+ * used here is for 32-bit code the one with 32-bit size and time
+ * fields, specifically called "_stat32".
+ *
+ * In Microsoft's compiler, by default "struct stat" means one with
+ * 64-bit time fields while in MinGW "struct stat" is the legacy one
+ * with 32-bit fields. To hopefully clear up this messs, the gstdio.h
+ * header defines a type GStatBuf which is the appropriate struct type
+ * depending on the platform and/or compiler being used. On POSIX it
+ * is just "struct stat", but note that even on POSIX platforms,
+ * "stat" might be a macro.
+ *
  * See your C library manual for more details about stat().
  *
  * Returns: 0 if the information was successfully retrieved, -1 if an error 
@@ -443,7 +468,7 @@ g_chdir (const gchar *path)
  */
 int
 g_stat (const gchar *filename,
-	struct stat *buf)
+	GStatBuf    *buf)
 {
 #ifdef G_OS_WIN32
   wchar_t *wfilename = g_utf8_to_utf16 (filename, -1, NULL, NULL, NULL);
@@ -464,7 +489,7 @@ g_stat (const gchar *filename,
       (!g_path_is_absolute (filename) || len > g_path_skip_root (filename) - filename))
     wfilename[len] = '\0';
 
-  retval = _wstat (wfilename, (struct _stat *) buf);
+  retval = _wstat (wfilename, buf);
   save_errno = errno;
 
   g_free (wfilename);
@@ -497,7 +522,7 @@ g_stat (const gchar *filename,
  */
 int
 g_lstat (const gchar *filename,
-	 struct stat *buf)
+	 GStatBuf    *buf)
 {
 #ifdef HAVE_LSTAT
   /* This can't be Win32, so don't do the widechar dance. */
@@ -806,6 +831,3 @@ g_utime (const gchar    *filename,
   return utime (filename, utb);
 #endif
 }
-
-#define __G_STDIO_C__
-#include "galiasdef.c"
